pyhsm.basic_cmd

Package pyhsm :: Module basic_cmd |
[frames] | no frames]

# Module basic_cmd

implementations of basic commands to execute on a YubiHSM

Classes
| YHSM_Cmd_Echo Send something to the stick, and expect to get it echoed back.
| YHSM_Cmd_System_Info Request system information from the YubiHSM.
| YHSM_Cmd_Random Ask stick to generate a number of random bytes.
| YHSM_Cmd_Random_Reseed Provide YubiHSM DRBG_CTR with a new seed.
| YHSM_Cmd_Temp_Key_Load Load an AEAD into the phantom key handle 0xffffffff.
| YHSM_Cmd_Nonce_Get Get nonce value from YubiHSM - causes it to increment by one (or a specified number).
| YHSM_Cmd_Key_Storage_Unlock Have the YubiHSM unlock it's key storage using the HSM password.
| YHSM_Cmd_Key_Store_Decrypt Have the YubiHSM decrypt it's key store using the master key.
| YHSM_Cmd_HSM_Unlock Have the YubiHSM unlock the HSM operations (those involving the keystore) with a YubiKey OTP.
| YHSM_NonceResponse Small class to hold response of Nonce_Get command.